"""Routes configuration

The more specific and detailed routes should be defined first so they
may take precedent over the more generic routes. For more information
refer to the routes manual at http://routes.groovie.org/docs/
"""
from pylons import config
from routes import Mapper

def make_map():
    """Create, configure and return the routes Mapper"""
    map = Mapper(directory=config['pylons.paths']['controllers'],
                 always_scan=config['debug'])
    map.minimization = False

    # The ErrorController route (handles 404/500 error pages); it should
    # likely stay at the top, ensuring it can always be resolved
    map.connect('/error/{action}', controller='error')
    map.connect('/error/{action}/{id}', controller='error')

    # CUSTOM ROUTES HERE
    map.connect('domains', '/', controller='domains', action='index')
    map.connect('domain-new', '/domains/new', controller='domains', action='new')
    map.connect('domain-savenew', '/domains/savenew', controller='domains', action='savenew')
    map.connect('domain-delete', '/domains/:domain/delete', controller='domains', action='delete')
    map.connect('domain-actions', '/domains/:domain', controller='domains', action='actions')

    map.connect('users', '/users/:domain', controller='users', action='index')
    map.connect('users-new', '/users/:domain/new', controller='users', action='new')
    map.connect('users-savenew', '/users/:domain/savenew', controller='users', action='savenew')
    map.connect('users-edit', '/users/:domain/edit/:email', controller='users', action='edit')
    map.connect('users-save', '/users/:domain/save/:email', controller='users', action='save')
    map.connect('users-delete', '/users/:domain/delete/:email', controller='users', action='delete')
    map.connect('users-pointing-aliases', '/users/:domain/pointing-aliases/:email', controller='users', action='pointing_aliases')

    map.connect('aliases', '/:domain/aliases', controller='aliases', action='index')
    map.connect('aliases-new', '/aliases/:domain/new', controller='aliases', action='new')
    map.connect('aliases-savenew', '/aliases/:domain/savenew', controller='aliases', action='savenew')
    map.connect('aliases-edit', '/aliases/:domain/edit/:source', controller='aliases', action='edit')
    map.connect('aliases-save', '/aliases/:domain/save/:source', controller='aliases', action='save')
    map.connect('aliases-delete', '/aliases/:domain/delete/:source', controller='aliases', action='delete')
    map.connect('aliases-addrecipient', '/aliases/:domain/:source/addrecipient', controller='aliases', action='addrecipient')
    map.connect('aliases-delrecipient', '/aliases/:domain/:source/delrecipient/:destination', controller='aliases', action='delrecipient')
    map.connect('aliases-pointing-aliases', '/aliases/:domain/pointing-aliases/:email', controller='aliases', action='pointing_aliases')

    map.connect('admin-login', '/admin/login', controller='admin', action='login')
    map.connect('admin-login-submit', '/admin/login-submit', controller='admin', action='login_submit')
    map.connect('admin-logout', '/admin/logout', controller='admin', action='logout')

    #map.connect('/{controller}/{action}')
    #map.connect('/{controller}/{action}/{id}')

    return map
