import logging

from pylons import request, response, session, tmpl_context as c
from pylons.controllers.util import abort, redirect_to

from ispwebadmin.lib.base import BaseController, render, db, model
from ispwebadmin.lib import my
import formencode
import hashlib

log = logging.getLogger(__name__)


class ValidateLogin(formencode.Schema):
    allow_extra_fields = True
    
    username = formencode.validators.UnicodeString(max=40, not_empty=True)
    password = formencode.validators.UnicodeString(max=40, not_empty=True)


class AdminController(BaseController):
    def login(self):
        """Show login form"""
        return render('/admin/loginform.mako')

    def login_submit(self):
        """Check input from login form"""
        try:
            fields = my.validate(ValidateLogin)
        except formencode.Invalid, e:
            return my.htmlfill(self.login(), e)

        # Get admin user object
        admin = db.query(model.Admin).filter_by(username=fields['username']).first()
        if not admin:
            c.message = 'Login failed.'
            log.warn('Login failed: Username %s does not exist', fields['username'])
            #return self.login()
            return my.htmlfill(self.login())
            
        # Verify password
        if admin.pwhash != hashlib.md5(fields['password']).hexdigest():
            c.message = 'Login failed.'
            log.warn('Login failed: Password incorrect for admin user %s', fields['username'])
            #return self.login()
            return my.htmlfill(self.login())

        # Login succeeded
        log.info("Admin user %s logged in.", fields['username'])
        session['admin'] = fields['username']
        session.save()
        redirect_to('/')

    def logout(self):
        """Log the current admin user out"""
        if session.get('admin'):
            log.info("Admin user %s logged out.", session['admin'])
            del session['admin']
            session.save()
        redirect_to('/')
        