# -*- coding: utf-8 -*-

import pylons
import formencode
import string
import random

def validate(schema, **state_kwargs):
    """Validierung eines Formencode-validators. Ähnlich wie der @validate-Decorator.
    Gibt bei Erfolg ein Dictionary der Werte von request.params zurück oder sonst wirft eine
    formencode.Invalid-Exception."""
    if state_kwargs:
        state = State(**state_kwargs)
    else:
        state = None

    # Sollten bei der Validierung Fehler gefunden werden, wird eine
    # formencode.Invalid-Exception geworfen. Die muss an anderer Stelle
    # abgefangen werden.
    #print dict(pylons.request.params)
    return schema.to_python(pylons.request.params, state)

def htmlfill(html, exception_error=None):
    """Füllt einen HTML-String mit Fehlermeldungen aus der letzten Formencode-Validierung.
    html beinhaltet die HTML-Seite mit dem Formular (z.B. von render()) und
    exception_error beinhaltet die formencode.Invalid-Exception von Formencode."""
    if exception_error:
        errors=exception_error.unpack_errors()
    else:
        errors=None

    return formencode.htmlfill.render(
        form=html,
        defaults=pylons.request.params,
        errors=errors,
        encoding=pylons.response.determine_charset()
    )

def random_password(size):
    """Return a random password consisting of lowercase letters and numbers"""
    return ''.join([random.choice(string.lowercase + string.digits) for i in range(size)])
